#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 securemem
version:              0.1.10
visibility:           public
id:                   securemem-0.1.10-Br9Q9tBlWmQ2Cli31Z6NJv
key:                  securemem-0.1.10-Br9Q9tBlWmQ2Cli31Z6NJv
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           vincent@snarc.org
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/vincenthz/hs-securemem
synopsis:
    abstraction to an auto scrubbing and const time eq, memory chunk.

description:
    SecureMem is similar to ByteString, except that it provides a memory chunk that
    will be auto-scrubbed after it run out of scope.

category:             Data
abi:                  59d490b45a1022eac166602868e15cff
exposed:              True
exposed-modules:      Data.SecureMem
import-dirs:          /usr/lib/ghc-9.6.6/site-local/securemem-0.1.10
library-dirs:         /usr/lib/ghc-9.6.6/site-local/securemem-0.1.10
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/securemem-0.1.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-securemem
hs-libraries:         HSsecuremem-0.1.10-Br9Q9tBlWmQ2Cli31Z6NJv
depends:
    base-4.18.2.1 byteable-0.1.1-3f80cduirhUG2oEjYYiPCW
    bytestring-0.11.5.3 ghc-prim-0.10.0
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5

haddock-interfaces:   /usr/share/doc/haskell-securemem/html/securemem.haddock
haddock-html:         /usr/share/doc/haskell-securemem/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

